@@ -1,11 +1,12 @@
-// SPDX-License-Identifier: MIT OR Unlicense
+// SPDX-License-Identifier: MIT
 
 package processor
 
 import (
-	"github.com/mattn/go-runewidth"
 	"strings"
 	"testing"
+
+	"github.com/mattn/go-runewidth"
 )
 
 func TestPrintTrace(t *testing.T) {
@@ -737,19 +738,19 @@ func TestToOpenMetricsMultiple(t *testing.T) {
 	res := toOpenMetrics(inputChan)
 	Debug = false
 
-	var expectedResult = `# TYPE scc_files count
+	var expectedResult = `# TYPE scc_files gauge
 # HELP scc_files Number of sourcecode files.
-# TYPE scc_lines count
+# TYPE scc_lines gauge
 # HELP scc_lines Number of lines.
-# TYPE scc_code count
+# TYPE scc_code gauge
 # HELP scc_code Number of lines of actual code.
-# TYPE scc_comments count
+# TYPE scc_comments gauge
 # HELP scc_comments Number of comments.
-# TYPE scc_blanks count
+# TYPE scc_blanks gauge
 # HELP scc_blanks Number of blank lines.
-# TYPE scc_complexity count
+# TYPE scc_complexity gauge
 # HELP scc_complexity Code complexity.
-# TYPE scc_bytes count
+# TYPE scc_bytes gauge
 # UNIT scc_bytes bytes
 # HELP scc_bytes Size in bytes.
 scc_files{language="Go"} 2
@@ -781,6 +782,7 @@ func TestToSQLSingle(t *testing.T) {
 		Complexity:         1000,
 		WeightedComplexity: 1000,
 		Binary:             false,
+		Uloc:               99,
 	}
 	close(inputChan)
 	Files = false
@@ -800,7 +802,7 @@ func TestToSQLSingle(t *testing.T) {
 		t.Error("Expected begin transaction return", res)
 	}
 
-	if !strings.Contains(res, `insert into t values('', 'Go', './', './', 'bbbb.go', 1000, 1000, 1000, 1000, 1000);`) {
+	if !strings.Contains(res, `insert into t values('', 'Go', './', './', 'bbbb.go', 1000, 1000, 1000, 1000, 1000, 99);`) {
 		t.Error("Expected insert return", res)
 	}
 
@@ -969,19 +971,19 @@ func TestFileSummarizeOpenMetrics(t *testing.T) {
 	More = false
 	res := fileSummarize(inputChan)
 
-	var expectedResult = `# TYPE scc_files count
+	var expectedResult = `# TYPE scc_files gauge
 # HELP scc_files Number of sourcecode files.
-# TYPE scc_lines count
+# TYPE scc_lines gauge
 # HELP scc_lines Number of lines.
-# TYPE scc_code count
+# TYPE scc_code gauge
 # HELP scc_code Number of lines of actual code.
-# TYPE scc_comments count
+# TYPE scc_comments gauge
 # HELP scc_comments Number of comments.
-# TYPE scc_blanks count
+# TYPE scc_blanks gauge
 # HELP scc_blanks Number of blank lines.
-# TYPE scc_complexity count
+# TYPE scc_complexity gauge
 # HELP scc_complexity Code complexity.
-# TYPE scc_bytes count
+# TYPE scc_bytes gauge
 # UNIT scc_bytes bytes
 # HELP scc_bytes Size in bytes.
 scc_files{language="Go"} 1
@@ -1021,19 +1023,19 @@ func TestFileSummarizeOpenMetricsPerFile(t *testing.T) {
 	Files = true
 	res := fileSummarize(inputChan)
 
-	var expectedResult = `# TYPE scc_files count
+	var expectedResult = `# TYPE scc_files gauge
 # HELP scc_files Number of sourcecode files.
-# TYPE scc_lines count
+# TYPE scc_lines gauge
 # HELP scc_lines Number of lines.
-# TYPE scc_code count
+# TYPE scc_code gauge
 # HELP scc_code Number of lines of actual code.
-# TYPE scc_comments count
+# TYPE scc_comments gauge
 # HELP scc_comments Number of comments.
-# TYPE scc_blanks count
+# TYPE scc_blanks gauge
 # HELP scc_blanks Number of blank lines.
-# TYPE scc_complexity count
+# TYPE scc_complexity gauge
 # HELP scc_complexity Code complexity.
-# TYPE scc_bytes count
+# TYPE scc_bytes gauge
 # UNIT scc_bytes bytes
 # HELP scc_bytes Size in bytes.
 scc_lines{language="Go",file="C:\\bbbb.go"} 1000
@@ -1315,21 +1317,36 @@ func TestGetTabularShortBreak(t *testing.T) {
 }
 
 func TestGetTabularWideBreak(t *testing.T) {
-	Ci = false
-	r := getTabularWideBreak()
-
-	if !strings.Contains(r, "─") {
-		t.Errorf("Expected to have box line")
+	{
+		Ci, HBorder = false, false
+		r := getTabularWideBreak()
+		if !strings.Contains(r, "─") {
+			t.Errorf("Expected to have box line")
+		}
+	}
+	{
+		Ci, HBorder = false, true
+		r := getTabularWideBreak()
+		if strings.Contains(r, "─") {
+			t.Errorf("Didn't expect to have box line")
+		}
+	}
+	{
+		Ci, HBorder = true, false
+		r := getTabularWideBreak()
+		if !strings.Contains(r, "-") {
+			t.Errorf("Expected to have hyphen")
+		}
+	}
+	{
+		Ci, HBorder = true, true
+		r := getTabularWideBreak()
+		if strings.Contains(r, "-") {
+			t.Errorf("Didn't expect to have hyphen")
+		}
 	}
 
-	Ci = true
-	r = getTabularWideBreak()
-
-	if !strings.Contains(r, "-") {
-		t.Errorf("Expected to have hyphen")
-	}
-
-	Ci = false
+	Ci, HBorder = false, false
 }
 
 func TestToHTML(t *testing.T) {
